import "core-js/modules/es.object.keys.js";
import "core-js/modules/es.symbol.js";
import "core-js/modules/es.array.filter.js";
import "core-js/modules/es.object.get-own-property-descriptor.js";
import "core-js/modules/web.dom-collections.for-each.js";
import "core-js/modules/es.object.get-own-property-descriptors.js";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.to-string.js";
import "core-js/modules/web.queue-microtask.js";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import ReactReconciler from 'react-reconciler';
import createElement from "./createElement";
import { SmartElement } from "./elements";
import { dev } from "./util";

var logger = _objectSpread(_objectSpread({}, console), {}, {
  debug: function debug() {
    return undefined;
  }
}); // bindings to the react reconciliation lifecycle methods


export default ReactReconciler({
  createInstance: function createInstance(type, props, _rootContainerInstance, _hostContext) {
    logger.debug('createInstance');
    return createElement(type, props);
  },
  appendInitialChild: function appendInitialChild(parentInstance, child) {
    logger.debug('appendInitialChild');
    parentInstance.appendChild(child);
  },
  finalizeInitialChildren: function finalizeInitialChildren(_parentInstance, _type, _props, _rootContainerInstance, _hostContext) {
    logger.debug('finalizeInitialChildren');
    return true;
  },
  createTextInstance: function createTextInstance(text, _rootContainerInstance, _hostContext) {
    logger.debug('createTextInstance');
    var label = new SmartElement({
      code: text
    }, {});
    label.commitMount(); // prob should run at a later point

    return label;
  },
  getPublicInstance: function getPublicInstance(instance) {
    logger.debug('getPublicInstance');
    return instance;
  },
  prepareForCommit: function prepareForCommit(_containerInfo) {
    logger.debug('prepareForCommit');
    return null;
  },
  prepareUpdate: function prepareUpdate(_instance, _type, _oldProps, _newProps, _rootContainerInstance, _hostContext) {
    logger.debug('prepareUpdate');
    return true;
  },
  resetAfterCommit: function resetAfterCommit(_containerInfo) {
    logger.debug('resetAfterCommit');
  },
  resetTextContent: function resetTextContent(_instance) {
    logger.debug('resetTextContent'); // noop
  },
  commitTextUpdate: function commitTextUpdate(_textInstance, _oldText, _newText) {
    logger.debug('commitTextUpdate');
    throw new Error('commitTextUpdate should not be called');
  },
  removeChild: function removeChild(parentInstance, child) {
    logger.debug('removeChild');
    parentInstance.removeChild(child);
  },
  removeChildFromContainer: function removeChildFromContainer(_container, _child) {
    logger.debug('removeChildFromContainer');
    if (dev) logger.warn("'removeChildFromContainer' not supported");
  },
  insertBefore: function insertBefore(_parentInstance, _child, _beforeChild) {
    logger.debug('insertBefore');
    if (dev) logger.warn("'insertBefore' not supported");
  },
  appendChildToContainer: function appendChildToContainer(container, child) {
    logger.debug('appendChildToContainer');
    container.appendChild(child);
  },
  appendChild: function appendChild(parentInstance, child) {
    logger.debug('appendChild');
    parentInstance.appendChild(child);
  },
  shouldSetTextContent: function shouldSetTextContent(_type, props) {
    logger.debug('shouldSetTextContent');
    if (typeof props.children === 'string') return true;
    return false;
  },
  getRootHostContext: function getRootHostContext(_rootContainerInstance) {
    logger.debug('getRootHostContext');
    if (dev) logger.warn("'getRootHostContext' not supported");
    return {};
  },
  getChildHostContext: function getChildHostContext(_parentHostContext, _type, _rootContainerInstance) {
    logger.debug('getChildHostContext');
    if (dev) logger.warn("'getChildHostContext' not supported");
    return {};
  },
  now: Date.now,
  commitUpdate: function commitUpdate(instance, _updatePayload, _type, _oldProps, newProps) {
    logger.debug('commitUpdate');
    return instance.commitUpdate(newProps);
  },
  commitMount: function commitMount(instance, _type, _newProps) {
    logger.debug('commitMount');
    instance.commitMount();
  },
  scheduleTimeout: function scheduleTimeout(handler, timeout) {
    logger.debug('setTimeout');
    return setTimeout(handler, timeout);
  },
  cancelTimeout: function cancelTimeout(handle) {
    logger.debug('clearTimeout');
    return clearTimeout(handle);
  },
  preparePortalMount: function preparePortalMount() {
    logger.debug('preparePortalMount');
  },
  queueMicrotask: function (_queueMicrotask) {
    function queueMicrotask(_x) {
      return _queueMicrotask.apply(this, arguments);
    }

    queueMicrotask.toString = function () {
      return _queueMicrotask.toString();
    };

    return queueMicrotask;
  }(function (callback) {
    queueMicrotask(callback);
  }),
  clearContainer: function clearContainer(_container) {
    logger.debug('clearContainer');
  },
  noTimeout: -1,
  isPrimaryRenderer: true,
  supportsMutation: true,
  supportsPersistence: false,
  supportsHydration: false
});
//# sourceMappingURL=reconciler.js.map